@@ -21,9 +21,4 @@ from django.contrib import admin
 from models import *
 
 admin.site.register(Profile)
-admin.site.register(Place)
-admin.site.register(Followed)
-admin.site.register(Page)
-admin.site.register(Basket)
-admin.site.register(Sellable)
-admin.site.register(Deliverable)
+admin.site.register(Followed)
\ No newline at end of file
