@@ -20,7 +20,7 @@ class ExternalPaymentOrderForm(OrderForm):
        (1, "PayPal"),
        (2, "PagSeguro"), 
    	)
-   	pay_option = ChoiceField(widget=RadioSelect,choices=GATEWAYS)
+   	card_pay_option = ChoiceField(widget=RadioSelect,choices=GATEWAYS)
 	def __init__(self,*args,**kwargs):
 		super(ExternalPaymentOrderForm,self).__init__(*args,**kwargs)
 		del self.fields['card_expiry_year']
